Crate wiggle_runtime
wiggle_
runtime
0.13.0
All Items
Crate Items
Structs
Enums
Traits
Crate
wiggle_
runtime
Structs

Guest
Borrows
Guest
Ptr
A
guest
pointer into host memory.
Region
Represents a contiguous region in memory.
Enums

Guest
Error
Traits

Guest
Error
Type
Guest
Memory
A trait which abstracts how to get at the region of host memory taht contains guest memory.
Guest
Type
A trait for types that are intended to be pointees in
GuestPtr<T>
.
Guest
Type
Transparent
A trait for
GuestType
s that have the same representation in guest memory as in Rust. These types can be used with the
GuestPtr::as_raw
method to view as a slice.
Pointee
Types that can be pointed to by
GuestPtr<T>
.